@@ -5,24 +5,23 @@ import numpy as np
 import pandas as pd
 import scanpy as sc
 
+from . import checkatlas, folders
+from .metrics.cluster import clust_compute
+
+# try:
+#     from .metrics.cluster import clust_compute
 # except ImportError:
-#    from metrics.cluster import clust_compute
+#     from metrics.cluster import clust_compute
 # try:
 #     from .metrics.dim_red import dr_compute
 # except ImportError:
 #     from metrics.dim_red import dr_compute
-# try:
-# local imports
-# try:
-from . import checkatlas, folders
 
-# except ImportError:
-#    import checkatlas
 # try:
-# from .metrics.cluster import clust_compute
-
+#     from . import checkatlas, folders
 # except ImportError:
-#    import folders
+#     import folders
+#     import checkatlas
 
 
 """
@@ -86,10 +85,11 @@ def clean_scanpy_atlas(adata, atlas_info) -> bool:
     print("Clean scanpy:" + atlas_info[0])
     # If OBS_CLUSTERS are present and in int32 -> be sure to
     # transform them in categorical
-    obs_keys = get_viable_obs(adata)
-    for obs_key in obs_keys:
-        if adata.obs[obs_key].dtype == np.int32:
-            adata.obs[obs_key] = pd.Categorical(adata.obs[obs_key])
+    for obs_key in adata.obs_keys():
+        for obs_key_celltype in OBS_CLUSTERS:
+            if obs_key_celltype in obs_key:
+                if adata.obs[obs_key].dtype == np.int32:
+                    adata.obs[obs_key] = pd.Categorical(adata.obs[obs_key])
     return adata
 
 
@@ -249,21 +249,14 @@ def create_umap_fig(adata, atlas_path, atlas_info, path) -> None:
     r = re.compile(".*umap*.")
     print(len(list(filter(r.match, adata.obsm_keys()))))
     if len(list(filter(r.match, adata.obsm_keys()))) > 0:
-        # Create umap
-        found = False
-        i = 0
         # Setting up figures directory
         sc.settings.figdir = folders.get_workingdir(path)
         umap_path = os.sep + atlas_name + checkatlas.UMAP_EXTENSION
         # Exporting umap
-        while not found:
-            if OBS_CLUSTERS[i] in adata.obs_keys():
-                sc.pl.umap(
-                    adata, color=OBS_CLUSTERS[i], show=False, save=umap_path
-                )
-                found = True
-            i += 1
-        if not found:
+        obs_keys = get_viable_obs(adata)
+        if len(obs_keys) != 0:
+            sc.pl.umap(adata, color=obs_keys[0], show=False, save=umap_path)
+        else:
             sc.pl.umap(adata, show=False, save=umap_path)
 
 
@@ -281,21 +274,14 @@ def create_tsne_fig(adata, atlas_path, atlas_info, path) -> None:
     atlas_name = atlas_info[0]
     r = re.compile(".*tsne*.")
     if len(list(filter(r.match, adata.obsm_keys()))) > 0:
-        # Create tsne
-        found = False
-        i = 0
         # Setting up figures directory
         sc.settings.figdir = sc.settings.figdir = folders.get_workingdir(path)
         tsne_path = os.sep + atlas_name + checkatlas.TSNE_EXTENSION
         # Exporting tsne
-        while not found:
-            if OBS_CLUSTERS[i] in adata.obs_keys():
-                sc.pl.tsne(
-                    adata, color=OBS_CLUSTERS[i], show=False, save=tsne_path
-                )
-                found = True
-            i += 1
-        if not found:
+        obs_keys = get_viable_obs(adata)
+        if len(obs_keys) != 0:
+            sc.pl.tsne(adata, color=obs_keys[0], show=False, save=tsne_path)
+        else:
             sc.pl.tsne(adata, show=False, save=tsne_path)
 
 
@@ -321,10 +307,10 @@ def metric_cluster(adata, atlas_path, atlas_info, path) -> None:
         if len(annotations.cat.categories) != 1:
             silhouette = 1
             print("Calc Silhouette for " + atlas_name, obs_key)
-            # silhouette = clust_compute.silhouette(adata, obs_key, "X_umap")
+            silhouette = clust_compute.silhouette(adata, obs_key, "X_umap")
             daviesb = -1
             print("Calc Davies Bouldin for " + atlas_name, obs_key)
-            # daviesb = clust_compute.davies_bouldin(adata, obs_key, "X_umap")
+            daviesb = clust_compute.davies_bouldin(adata, obs_key, "X_umap")
             df_line = pd.DataFrame(
                 {
                     "Sample": [atlas_name + "_" + obs_key],
